pilas.actores.martian

Package pilas :: Package actores :: Module martian |
[hide private]
[frames] | no frames]

# Module martian

source code

Classes | [hide private]
| Martian Es un personaje de un marciano que puede caminar, saltar y disparar.
| Esperando Representa al actor en posicion normal.
| Caminando Representa al actor caminando hacia la izquierda o derecha.
| Saltando Representa al actor realizando un salto.
| Disparar Representa al actor disparando un proyectil.

Variables | [hide private]
| VELOCIDAD = `100`
| __package__ = ``'``pilas.actores``'``